@@ -13,7 +13,7 @@ class OptionCoveralls(Option):
     def root_dir(self):
         return Path(__file__).parent
 
-    def require_option(self):
+    def require_option(self, cfg):
         return ['coverage', 'travis']
 
     def require(self, cfg):
