@@ -18,5 +18,5 @@ class OptionData(Option):
         )
         cfg[self._name] = sec
 
-    def require_option(self):
+    def require_option(self, cfg):
         return ['src']
