@@ -17,7 +17,7 @@ class OptionGit(Option):
     def root_dir(self):
         return Path(__file__).parent
 
-    def require_option(self):
+    def require_option(self, cfg):
         return ['base']
 
     def environment_extensions(self, cfg):
