@@ -28,5 +28,5 @@ class OptionGithub(Option):
 
         return invalids
 
-    def require_option(self):
+    def require_option(self, cfg):
         return ['git']
