@@ -29,5 +29,5 @@ class OptionGitlab(Option):
 
         return invalids
 
-    def require_option(self):
+    def require_option(self, cfg):
         return ['git']
