@@ -12,15 +12,15 @@ class OptionTravis(Option):
     def root_dir(self):
         return Path(__file__).parent
 
-    def require_option(self):
+    def require_option(self, cfg):
         return ['doc', 'pysetup', 'github']
 
     def environment_extensions(self, cfg):
         owner = cfg['github']['owner']
         project = cfg['github']['project']
 
-        url = f"travis-ci.org/{owner}/{project}"
-        img = f"{url}.svg?branch=master"
+        url = f"travis-ci.com/github/{owner}/{project}"
+        img = f"api.travis-ci.com/{owner}/{project}.svg?branch=master"
         badge = fmt_badge(img, url, "Travis build status", cfg['doc']['fmt'])
 
         return {"badge": badge}
