@@ -36,7 +36,7 @@ class OptionVersion(Option):
 
         return invalids
 
-    def require_option(self):
+    def require_option(self, cfg):
         return ['src']
 
     def tools(self, cfg):
