@@ -8,8 +8,12 @@ def opt():
     return OptionBase('base')
 
 
-def test_update_parameters(opt):
-    cfg = {}
+@pytest.fixture()
+def cfg():
+    return Config()
+
+
+def test_update_parameters(opt, cfg):
     opt.update_parameters(cfg)
     assert len(cfg['base']) == 4
 
@@ -31,12 +35,11 @@ def test_config_check_pkg_names(opt):
         assert 'base.namespace' in opt.check(cfg)
 
 
-def test_require_option(opt):
-    assert len(tuple(opt.require_option())) == 0
+def test_require_option(opt, cfg):
+    assert len(tuple(opt.require_option(cfg))) == 0
 
 
-def test_require(opt):
-    cfg = Config()
+def test_require(opt, cfg):
     opt.update_parameters(cfg)
 
     assert len(tuple(opt.require(cfg))) == 0
