@@ -8,16 +8,21 @@ def opt():
     return OptionCoverage('coverage')
 
 
-def test_require_option(opt):
-    assert len(tuple(opt.require_option())) == 1
+@pytest.fixture()
+def cfg():
+    return Config()
 
 
-def test_require(opt):
-    cfg = Config(dict(test={'suite_name': 'pytest'}))
+def test_require_option(opt, cfg):
+    assert len(tuple(opt.require_option(cfg))) == 1
+
+
+def test_require(opt, cfg):
+    cfg['test'] = {'suite_name': 'pytest'}
     opt.update_parameters(cfg)
 
     assert len(tuple(opt.require(cfg))) == 2
 
-    cfg = Config(dict(test={'suite_name': 'nose'}))
+    cfg['test'] = {'suite_name': 'nose'}
     opt.update_parameters(cfg)
     assert len(tuple(opt.require(cfg))) == 1
