@@ -11,6 +11,11 @@ def opt():
     return OptionNotebook('notebook')
 
 
+@pytest.fixture()
+def cfg():
+    return Config()
+
+
 @pytest.fixture()
 def tmp_dir():
     pth = Path("nb_test_config")
@@ -21,26 +26,24 @@ def tmp_dir():
     rmdir(pth)
 
 
-def test_update_parameters(opt):
-    cfg = {}
+def test_update_parameters(opt, cfg):
     opt.update_parameters(cfg)
     assert len(cfg['notebook']) == 1
 
 
-def test_config_check_src_directory(opt, tmp_dir):
-    cfg = Config(dict(notebook={'src_directory': "failed_nb"}))
+def test_config_check_src_directory(opt, cfg, tmp_dir):
+    cfg['notebook'] = {'src_directory': "failed_nb"}
     assert 'notebook.src_directory' in opt.check(cfg)
 
-    cfg = Config(dict(notebook={'src_directory': tmp_dir}))
+    cfg['notebook'] = {'src_directory': tmp_dir}
     assert 'notebook.src_directory' not in opt.check(cfg)
 
 
-def test_require_option(opt):
-    assert len(tuple(opt.require_option())) == 1
+def test_require_option(opt, cfg):
+    assert len(tuple(opt.require_option(cfg))) == 1
 
 
-def test_require(opt):
-    cfg = Config()
+def test_require(opt, cfg):
     opt.update_parameters(cfg)
 
     assert len(tuple(opt.require(cfg))) == 0
