@@ -8,23 +8,26 @@ def opt():
     return OptionPypi('pypi')
 
 
-def test_update_parameters(opt):
-    cfg = {}
+@pytest.fixture()
+def cfg():
+    return Config()
+
+
+def test_update_parameters(opt, cfg):
     opt.update_parameters(cfg)
     assert len(cfg['pypi']) == 2
 
 
-def test_config_check_classifiers_exists(opt):
-    cfg = Config(dict(pypi={'classifiers': []}))
+def test_config_check_classifiers_exists(opt, cfg):
+    cfg['pypi'] = {'classifiers': []}
     assert 'pypi.classifiers' in opt.check(cfg)
 
 
-def test_require_option(opt):
-    assert len(tuple(opt.require_option())) == 2
+def test_require_option(opt, cfg):
+    assert len(tuple(opt.require_option(cfg))) == 2
 
 
-def test_require(opt):
-    cfg = Config()
+def test_require(opt, cfg):
     opt.update_parameters(cfg)
 
     assert len(tuple(opt.require(cfg))) == 1
