@@ -8,23 +8,26 @@ def opt():
     return OptionPysetup('pysetup')
 
 
-def test_update_parameters(opt):
-    cfg = {}
+@pytest.fixture()
+def cfg():
+    return Config()
+
+
+def test_update_parameters(opt, cfg):
     opt.update_parameters(cfg)
     assert len(cfg['pysetup']) == 1
 
 
-def test_config_check_intended_version_exists(opt):
-    cfg = Config(dict(pysetup={'intended_versions': []}))
+def test_config_check_intended_version_exists(opt, cfg):
+    cfg['pysetup'] = {'intended_versions': []}
     assert 'pysetup.intended_versions' in opt.check(cfg)
 
 
-def test_require_option(opt):
-    assert len(tuple(opt.require_option())) == 5
+def test_require_option(opt, cfg):
+    assert len(tuple(opt.require_option(cfg))) == 5
 
 
-def test_require(opt):
-    cfg = Config()
+def test_require(opt, cfg):
     opt.update_parameters(cfg)
 
     assert len(tuple(opt.require(cfg))) == 0
