@@ -8,23 +8,26 @@ def opt():
     return OptionReadthedocs('readthedocs')
 
 
-def test_update_parameters(opt):
-    cfg = {}
+@pytest.fixture()
+def cfg():
+    return Config(dict(github={}))
+
+
+def test_update_parameters(opt, cfg):
     opt.update_parameters(cfg)
     assert len(cfg['readthedocs']) == 1
 
 
-def test_config_check_project_exists(opt):
-    cfg = Config(dict(readthedocs={'project': ""}))
+def test_config_check_project_exists(opt, cfg):
+    cfg['readthedocs'] = {'project': ""}
     assert 'readthedocs.project' in opt.check(cfg)
 
 
-def test_require_option(opt):
-    assert len(tuple(opt.require_option())) == 3
+def test_require_option(opt, cfg):
+    assert len(tuple(opt.require_option(cfg))) == 3
 
 
-def test_require(opt):
-    cfg = Config()
+def test_require(opt, cfg):
     opt.update_parameters(cfg)
 
     assert len(tuple(opt.require(cfg))) == 0
